Exception: Ant::Exceptions::AntError
- Inherits:
-
AntBaseException
- Object
- StandardError
- AntBaseException
- Ant::Exceptions::AntError
- Defined in:
- lib/ant/exceptions.rb
Overview
Is used to express an error that was found during the execution of the program but it also means that the invoked endpoint has not the power to fix it, so it will only complain.
Instance Attribute Summary
Attributes inherited from AntBaseException
Instance Method Summary collapse
-
#initialize(message, code = nil, data = {}) ⇒ AntError
constructor
A new instance of AntError.
Constructor Details
#initialize(message, code = nil, data = {}) ⇒ AntError
48 49 50 51 52 |
# File 'lib/ant/exceptions.rb', line 48 def initialize(, code = nil, data = {}) code ||= self.class.name.split('::').last code = 'ServerError' if code == 'AntError' super(, code, data) end |